mlbench_core.lr_scheduler
-------------------------
.. autoapimodule:: mlbench_core.lr_scheduler
.. currentmodule:: mlbench_core.lr_scheduler

pytorch
~~~~~~~

.. autoapimodule:: mlbench_core.lr_scheduler.pytorch.lr
.. currentmodule:: mlbench_core.lr_scheduler.pytorch.lr

LRLinearWarmUp
++++++++++++++

.. autoapiclass:: LRLinearWarmUp
    :members:

MultiStepLRLinearWarmUp
+++++++++++++++++++++++

.. autoapiclass:: MultiStepLRLinearWarmUp
    :members:

ReduceLROnPlateauWithWarmup
+++++++++++++++++++++++++++

.. autoapiclass:: ReduceLROnPlateauWithWarmup
    :members:

SparsifiedSGDLR
+++++++++++++++

.. autoapiclass:: SparsifiedSGDLR
    :members:

TimeDecayLR
+++++++++++

.. autoapiclass:: TimeDecayLR
    :members:

SQRTTimeDecayLR
+++++++++++++++

.. autoapiclass:: SQRTTimeDecayLR
    :members:

ExponentialWarmupMultiStepLR
++++++++++++++++++++++++++++

.. autoapiclass:: ExponentialWarmupMultiStepLR
    :members:

SQRTTimeDecayLRWithWarmup
+++++++++++++++++++++++++

.. autoapiclass:: SQRTTimeDecayLRWithWarmup
    :members:

tensorflow
~~~~~~~~~~

.. autoapimodule:: mlbench_core.lr_scheduler.tensorflow
.. currentmodule:: mlbench_core.lr_scheduler.tensorflow

manual_stepping
+++++++++++++++

.. autoapifunction:: manual_stepping


.. rubric:: References


.. bibliography:: lr_scheduler.bib
   :cited: